@@ -2,12 +2,14 @@ from __future__ import absolute_import
 
 import datetime, hashlib, logging, time
 from copy import copy
+from lxml import etree
 from xml.etree import ElementTree
 
 from django.utils.datastructures import SortedDict
 from couchdbkit.exceptions import PreconditionFailed
 from couchdbkit.ext.django.schema import *
 from couchdbkit.resource import ResourceNotFound
+from dimagi.utils.couch import CouchDocLockableMixIn
 
 from dimagi.utils.indicators import ComputedDocumentMixin
 from dimagi.utils.parsing import string_to_datetime
@@ -84,10 +86,11 @@ class XFormOperation(DocumentSchema):
     """
     user = StringProperty()
     date = DateTimeProperty(default=datetime.datetime.utcnow)
-    operation = StringProperty() # e.g. "archived", "unarchived"
+    operation = StringProperty()  # e.g. "archived", "unarchived"
 
 
-class XFormInstance(SafeSaveDocument, UnicodeMixIn, ComputedDocumentMixin):
+class XFormInstance(SafeSaveDocument, UnicodeMixIn, ComputedDocumentMixin,
+                    CouchDocLockableMixIn):
     """An XForms instance."""
     xmlns = StringProperty()
     received_on = DateTimeProperty()
@@ -112,7 +115,7 @@ class XFormInstance(SafeSaveDocument, UnicodeMixIn, ComputedDocumentMixin):
         Returns a generator object of all forms submitted by user,
         from start to end dates, if specified.
         """
-        # Thew couchforms/by_user view returns a zero-indexed month
+        # The couchforms/by_user view returns a zero-indexed month
         # correct for this by subtracting 1 from month
         if start is not None:
             startkey = [user.user_id, start.year, start.month - 1, start.day]
@@ -122,11 +125,11 @@ class XFormInstance(SafeSaveDocument, UnicodeMixIn, ComputedDocumentMixin):
             endkey = [user.user_id, end.year, end.month - 1, end.day, {}]
         else:
             endkey = [user.user_id, {}]
-        results = cls.view(
+        results = cls.get_db().view(
             "couchforms/by_user",
             startkey=startkey,
             endkey=endkey,
-            reduce=False
+            reduce=False,
         ).all()
         docs = iter_docs(cls.get_db(), [r['id'] for r in results])
         return (cls(doc) for doc in docs)
@@ -163,9 +166,9 @@ class XFormInstance(SafeSaveDocument, UnicodeMixIn, ComputedDocumentMixin):
                 # (see https://github.com/benoitc/couchdbkit/blob/a23343e539370cffcf8b0ce483c712911bb022c1/couchdbkit/schema/properties.py#L1038)
                 if meta_block.get('appVersion') is not None and not isinstance(meta_block['appVersion'], basestring):
                     if isinstance(meta_block['appVersion'], dict) and '#text' in meta_block['appVersion']:
-                        ret['appVersion'] = str(meta_block['appVersion']['#text'])
+                        ret['appVersion'] = unicode(meta_block['appVersion']['#text'])
                     else:
-                        ret['appVersion'] = str(meta_block['appVersion'])
+                        ret['appVersion'] = unicode(meta_block['appVersion'])
 
                 if meta_block:
                     for key in ("timeStart", "timeEnd"):
@@ -238,7 +241,13 @@ class XFormInstance(SafeSaveDocument, UnicodeMixIn, ComputedDocumentMixin):
                 return self[const.TAG_XML]
             except AttributeError:
                 return None
-    
+
+    def get_xml_element(self):
+        xml = self.get_xml()
+        if isinstance(xml, unicode):
+            xml = xml.encode('utf-8')
+        return etree.fromstring(xml)
+
     @property
     def attachments(self):
         """
